import * as ec2 from '@aws-cdk/aws-ec2';
import * as ecs from '@aws-cdk/aws-ecs';
import * as cdk from '@aws-cdk/core';
/**
 * Options for the runner to create the fargate job executor.
 */
export interface JobExecutorOptions {
    /**
     * AWS region for the job executor.
     *
     * @default - the region of the stack
     */
    readonly region?: string;
    /**
     * The ECS clsuter of the job executor fargate task.
     *
     * @default - the cluster for the runner
     */
    readonly cluster?: ecs.ICluster;
    /**
     * subnet for the executor.
     */
    readonly subnet?: ec2.ISubnet;
    /**
     * security group for the executor.
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * task definition arn of the executor.
     */
    readonly task?: string;
}
/**
 *
 */
export interface FargateRunnerProps {
    /**
     * VPC for the fargate.
     */
    readonly vpc: ec2.IVpc;
    /**
     * tags for the runner.
     */
    readonly tags?: string[];
    /**
     * The security group for Fargate CI task.
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * subnet for fargate CI task.
     */
    readonly fargateJobSubnet?: ec2.SubnetSelection;
    /**
     * GitLab registration token for the runner.
     */
    readonly registrationToken?: string;
    /**
     * gitlab URL prefix.
     *
     * @default - 'https://gitlab.com'
     */
    readonly gitlabURL?: string;
    /**
     * Fargate job executor options.
     */
    readonly executor: JobExecutorOptions;
}
/**
 * The docker image for the job executor.
 */
export declare class JobExecutorImage {
    readonly uri: string;
    /**
     * Debian.
     *
     * @see https://gitlab.com/tmaczukin-test-projects/fargate-driver-debian
     */
    static readonly DEBIAN: JobExecutorImage;
    /**
     * Node.
     *
     * @see https://gitlab.com/aws-fargate-driver-demo/docker-nodejs-gitlab-ci-fargate
     */
    static readonly NODE: JobExecutorImage;
    /**
     * JSII for AWS CDK.
     *
     * @see https://gitlab.com/pahud/docker-jsii-cdk-gitlab-ci-fargate
     */
    static readonly JSII: JobExecutorImage;
    /**
     * Custom image.
     *
     * @param image custom image registry URI.
     */
    static of(image: string): JobExecutorImage;
    /**
     *
     * @param image job executor image URI
     */
    private constructor();
}
/**
 *
 */
export declare class FargateRunner extends cdk.Construct {
    /**
     *
     */
    readonly vpc: ec2.IVpc;
    /**
     *
     */
    constructor(scope: cdk.Construct, id: string, props: FargateRunnerProps);
    private synthesizeTags;
    private createSecurityGroup;
}
/**
 *
 */
export interface FargateJobExecutorProps {
    /**
     * The docker image for the job executor container.
     */
    readonly image?: JobExecutorImage;
}
/**
 *
 */
export declare class FargateJobExecutor extends cdk.Construct {
    /**
     * task definition arn.
     */
    readonly taskDefinitionArn: string;
    /**
     *
     */
    constructor(scope: cdk.Construct, id: string, props?: FargateJobExecutorProps);
}
